@@ -95,7 +95,7 @@ def process_image(image, contrast):
     # laplacian = cv2.Laplacian(blur, -1, ksize=17, delta=-50)
     # laplacian = cv2.Laplacian(thresh, cv2.CV_64F)
     laplacian = cv2.Laplacian(thresh, cv2.CV_8UC1)
-    # cv2.imwrite("./test_pic_laplacian.jpg", laplacian)
+    debug_info("./test_pic_laplacian.jpg", laplacian)
     # gray_lapl = cv2.cvtColor(laplacian, cv2.COLOR_BGR2GRAY)
 
     # binary = cv2.threshold(laplacian, 165, 255, cv2.THRESH_BINARY)
@@ -120,13 +120,15 @@ def draw_contours(image, green_df, red_df, other_df, plate_df):
     image_copy = image.copy()
     for index, green in green_df.iterrows():
         draw_one_contour(image_copy, green, (0, 255, 0))
-    #for index, red in red_df.iterrows():
-        #draw_one_contour(image_copy, red, (0, 0, 255))
-    #for index, other in other_df.iterrows():
-        #draw_one_contour(image_copy, other, (200, 150, 150))
-        #draw_one_contour(image_copy, other, (100, 100, 100))
-    #for index, plate in plate_df.iterrows():
-        #draw_one_contour(image_copy, plate, (0, 128, 255))
+        if debug_mode:
+            for index, red in red_df.iterrows():
+                draw_one_contour(image_copy, red, (0, 0, 255))
+            for index, other in other_df.iterrows():
+                # draw_one_contour(image_copy, other, (200, 150, 150))
+                draw_one_contour(image_copy, other, (100, 100, 100))
+            for index, plate in plate_df.iterrows():
+                draw_one_contour(image_copy, plate, (0, 128, 255))
+
     return image_copy
 
 
@@ -182,8 +184,8 @@ def write_one_data(out_dir, image_path, prefix, df):
     image_file_name = os.path.split(image_path)[1]
     image_name = os.path.splitext(image_file_name)[0]
     if df.empty != True:
-        df.to_csv(path_or_buf=f'{out_dir}/data-{prefix}-{image_name}.csv',
-                  columns=['INDEX_COL', 'AREA_PXL', 'PERIMETER_PXL', 'DIAMETER_PXL', 'AREA_MM2', 'DIAMETER_MM'])
+        df.to_csv(path_or_buf=f'{out_dir}/data-{prefix}-{image_name}.csv', index = False,
+                  columns=['INDEX_COL', 'AREA_PXL', 'DIAMETER_PXL', 'AREA_MM2', 'DIAMETER_MM'])
                   #columns=['INDEX_COL', 'AREA_PXL', 'PERIMETER_PXL', 'ENCL_CENTER', 'ENCL_DIAMETER_PXL'])
 
 
@@ -369,18 +371,21 @@ def main():
     for image_path in image_paths:
         print("Processing " + image_path)
 
+        # adjust too bright image
         #average image brightness
         image_brightness = get_brightness(image_path)
+        im = Image.open(image_path)
 
-        # adjust too bright image
-        if image_brightness > 90:
-            im = Image.open(image_path)
+        image = cv2.imread(image_path)
+        if image_brightness > 70:
+            #im = Image.open(image_tmp)
             enhancer = ImageEnhance.Brightness(im)
             factor = 0.5
             im_output = enhancer.enhance(factor)
-            im_output.save(image_path)
 
-        image = cv2.imread(image_path)
+            im_output.save(image_path + '.tmp' + os.path.splitext(image_path)[1])
+            image = cv2.imread(image_path + '.tmp' + os.path.splitext(image_path)[1])
+
 
         binary_image, high_contrast, clr_high_contrast = process_image(image, 2.5)
         #       cv2.imshow("Binary image", binary_image)
@@ -413,6 +418,7 @@ def main():
                 axis=1)
 
             #Remove extra black contours
+            #TODO dark plaques are being filtered out (online_image.png
             filter_dev_colour = green_df_copy.apply(lambda x: abs(x['MEAN_COLOUR'] ) < 40, axis=1)
             green_df_copy = green_df_copy[~filter_dev_colour]
         else:
@@ -428,6 +434,10 @@ def main():
             os.makedirs(out_dir_path)
         write_images(out_dir_path, output, binary_image, high_contrast, image_path)
 
+        #Delete the temporary file
+        if os.path.exists(image_path + '.tmp' + os.path.splitext(image_path)[1]):
+            os.remove(image_path + '.tmp' + os.path.splitext(image_path)[1])
+
         # format float values
         # green_df_copy['ENCL_DIAMETER_MM'] = green_df_copy['ENCL_DIAMETER_MM'].apply(lambda x: f"{x:.2f}")
         write_data(out_dir_path, image_path, green_df_copy, red_df_copy, other_df)
